@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 import logging
+from pathlib import Path
 
 from box import Box
 from qtpy import QtCore, QtGui, QtWidgets
@@ -60,9 +61,16 @@ class HEVC(SettingPanel):
         grid.addLayout(self.init_pix_fmt(), 6, 0, 1, 1)
         grid.addLayout(self.init_profile(), 7, 0, 1, 1)
 
-        grid.addLayout(self.init_modes(), 0, 1, 6, 5)
+        grid.addLayout(self.init_modes(), 0, 1, 5, 5)
+        grid.addLayout(self.init_hdr10(), 5, 1, 1, 1)
+        grid.addLayout(self.init_hdr10_opt(), 5, 2, 1, 1)
+        grid.addLayout(self.init_repeat_headers(), 5, 3, 1, 1)
+        grid.addLayout(self.init_aq_mode(), 5, 4, 1, 2)
         grid.addLayout(self.init_x265_params(), 6, 1, 1, 5)
 
+        grid.addLayout(self.init_dhdr10_info(), 7, 1, 1, 4)
+        grid.addWidget(self.init_dhdr10_warning(), 7, 5, 1, 4)
+
         grid.setRowStretch(9, True)
 
         grid.addLayout(self._add_custom(), 10, 0, 1, 6)
@@ -71,6 +79,8 @@ class HEVC(SettingPanel):
             "<a href='https://trac.ffmpeg.org/wiki/Encode/H.265'>FFMPEG HEVC / H.265 Encoding Guide</a>"
             " | <a href='https://codecalamity.com/encoding-uhd-4k-hdr10-videos-with-ffmpeg/'>"
             "CodeCalamity UHD HDR Encoding Guide</a>"
+            " | <a href='https://github.com/cdgriffith/FastFlix/wiki/HDR10-Plus-Metadata-Extraction'>"
+            "HDR10+ Metadata Extraction"
         )
         guide_label.setAlignment(QtCore.Qt.AlignBottom)
         guide_label.setOpenExternalLinks(True)
@@ -79,13 +89,90 @@ class HEVC(SettingPanel):
         self.setLayout(grid)
         self.hide()
 
+    def init_dhdr10_info(self):
+        return self._add_file_select(
+            label="HDR10+ Metadata",
+            widget_name="hdr10plus_metadata",
+            button_action=lambda: self.dhdr10_update(),
+            tooltip="dhdr10_info: Path to HDR10+ JSON metadata file",
+        )
+
+    def init_dhdr10_warning(self):
+        label = QtWidgets.QLabel()
+        label.setToolTip(
+            "WARNING: This only works on a few FFmpeg builds, and it will not raise error on failure!\n"
+            "Specifically, FFmpeg needs the x265 ENABLE_HDR10_PLUS option enabled on compile.\n"
+            "The latest windows builds from BtbN should have this feature.\n"
+            "I do not know of any public Linux/Mac ones that do."
+        )
+        icon = self.style().standardIcon(QtWidgets.QStyle.SP_MessageBoxWarning)
+        label.setPixmap(icon.pixmap(16))
+        # label.style().standardIcon(QtWidgets.QStyle.SP_MessageBoxWarning)
+        return label
+
+    def init_hdr10(self):
+        return self._add_check_box(
+            label="Force HDR10 signaling",
+            widget_name="hdr10",
+            tooltip=(
+                "hdr10: Force signaling of HDR10 parameters in SEI packets.\n"
+                " Enabled automatically when --master-display or --max-cll is specified.\n"
+                " Useful when there is a desire to signal 0 values for max-cll and max-fall.\n"
+                " Default disabled."
+            ),
+            checked=True,
+        )
+
+    def init_hdr10_opt(self):
+        return self._add_check_box(
+            label="| HDR10 Optimizations",
+            widget_name="hdr10_opt",
+            tooltip=(
+                "hdr10-opt: Enable block-level luma and chroma QP optimization for HDR10 content.\n"
+                "It is recommended that AQ-mode be enabled along with this feature"
+            ),
+            checked=False,
+        )
+
+    def init_repeat_headers(self):
+        return self._add_check_box(
+            label="| Repeat Headers",
+            widget_name="repeat_headers",
+            tooltip=(
+                "repeat-headers: If enabled, x265 will emit VPS, SPS, and PPS headers with every keyframe.\n"
+                "This is intended for use when you do not have a container to keep the stream headers for you\n"
+                " and you want keyframes to be random access points."
+            ),
+            checked=True,
+        )
+
+    def init_aq_mode(self):
+        return self._add_combo_box(
+            label="| Adaptive Quantization",
+            widget_name="aq_mode",
+            options=[
+                "disabled",
+                "enabled",
+                "enabled + auto-variance",
+                "enabled + av + dark bias",
+                "enabled + av + edge",
+            ],
+            tooltip=(
+                "aq-mode: Adaptive Quantization operating mode.\n"
+                "Raise or lower per-block quantization based on complexity analysis of the source image.\n"
+                "The more complex the block, the more quantization is used.\n"
+                "Default: AQ enabled with auto-variance"
+            ),
+            default=2,
+        )
+
     def init_intra_encoding(self):
         return self._add_combo_box(
             label="Intra-encoding",
             widget_name="intra_encoding",
             options=["No", "Yes"],
             tooltip=(
-                "Enable Intra-Encoding by forcing keyframes every 1 second (Blu-ray spec)\n"
+                "keyint: Enable Intra-Encoding by forcing keyframes every 1 second (Blu-ray spec)\n"
                 "This option is not recommenced unless you need to conform "
                 "to Blu-ray standards to burn to a physical disk"
             ),
@@ -109,7 +196,7 @@ class HEVC(SettingPanel):
                 "placebo",
             ],
             tooltip=(
-                "The slower the preset, the better the compression and quality\n"
+                "preset: The slower the preset, the better the compression and quality\n"
                 "Slow is highest personal recommenced, as past that is much smaller gains"
             ),
             connect="default",
@@ -121,14 +208,14 @@ class HEVC(SettingPanel):
             label="Tune",
             widget_name="tune",
             options=["default", "psnr", "ssim", "grain", "zerolatency", "fastdecode", "animation"],
-            tooltip="Tune the settings for a particular type of source or situation",
+            tooltip="tune: Tune the settings for a particular type of source or situation",
             connect="default",
         )
 
     def init_profile(self):
         return self._add_combo_box(
             label="Profile",
-            tooltip="Enforce an encode profile",
+            tooltip="profile: Enforce an encode profile",
             widget_name="profile",
             options=["default", "main", "main10", "mainstillpicture"],
             default=0,
@@ -147,7 +234,9 @@ class HEVC(SettingPanel):
     def init_max_mux(self):
         return self._add_combo_box(
             label="Max Muxing Queue Size",
-            tooltip='Useful when you have the "Too many packets buffered for output stream" error',
+            tooltip=(
+                "max_muxing_queue_size: " 'Useful when you have the "Too many packets buffered for output stream" error'
+            ),
             widget_name="max_mux",
             options=["default", "1024", "2048", "4096", "8192"],
             default=1,
@@ -229,7 +318,7 @@ class HEVC(SettingPanel):
         tool_tip = (
             "Extra x265 params in opt=1:opt2=0 format,\n"
             "cannot modify generated settings\n"
-            "examples: aq-mode=3:rc-lookahead=10 "
+            "examples: level-idc=4.1:rc-lookahead=10 "
         )
         self.labels.x265_params.setToolTip(tool_tip)
         layout.addWidget(self.labels.x265_params)
@@ -239,19 +328,46 @@ class HEVC(SettingPanel):
         layout.addWidget(self.widgets.x265_params)
         return layout
 
+    def dhdr10_update(self):
+        dirname = Path(self.widgets.hdr10plus_metadata.text()).parent
+        if not dirname.exists():
+            dirname = Path()
+        filename = QtWidgets.QFileDialog.getOpenFileName(
+            self, caption="hdr10_metadata", directory=str(dirname), filter="HDR10+ Metadata (*.json)"
+        )
+        if not filename or not filename[0]:
+            return
+        self.widgets.hdr10plus_metadata.setText(filename[0])
+        self.main.page_update()
+
     def setting_change(self, update=True, pix_change=False):
         if self.updating_settings:
             return
-        if pix_change:
-            self.main.page_update()
-            return
         self.updating_settings = True
+        if pix_change:
+            if self.widgets.pix_fmt.currentText().startswith("8-bit"):
+                self.widgets.hdr10_opt.setDisabled(True)
+                self.widgets.hdr10_opt.setChecked(False)
+                self.widgets.hdr10.setDisabled(True)
+                self.widgets.hdr10.setChecked(False)
+            else:
+                self.widgets.hdr10.setDisabled(False)
+                self.widgets.hdr10.setChecked(True)
+                self.widgets.hdr10_opt.setDisabled(False)
+            self.main.page_update()
+            self.updating_settings = False
+            return
+
         remove_hdr = self.widgets.remove_hdr.currentIndex()
         bit_depth = self.main.streams["video"][self.main.video_track].bit_depth
         if remove_hdr == 1:
             self.widgets.pix_fmt.clear()
             self.widgets.pix_fmt.addItems([pix_fmts[0]])
             self.widgets.pix_fmt.setCurrentIndex(0)
+            self.widgets.hdr10_opt.setDisabled(True)
+            self.widgets.hdr10_opt.setChecked(False)
+            self.widgets.hdr10.setDisabled(True)
+            self.widgets.hdr10.setChecked(False)
         else:
             self.widgets.pix_fmt.clear()
             if bit_depth == 12:
@@ -263,10 +379,18 @@ class HEVC(SettingPanel):
             else:
                 self.widgets.pix_fmt.addItems(pix_fmts)
                 self.widgets.pix_fmt.setCurrentIndex(1)
+            if not self.widgets.pix_fmt.currentText().startswith("8-bit"):
+                self.widgets.hdr10_opt.setDisabled(False)
+                self.widgets.hdr10.setDisabled(False)
+                self.widgets.hdr10.setChecked(True)
         if update:
             self.main.page_update()
         self.updating_settings = False
 
+    def new_source(self):
+        super().new_source()
+        self.setting_change()
+
     def get_settings(self):
         settings = Box(
             disable_hdr=bool(self.widgets.remove_hdr.currentIndex()),
@@ -275,10 +399,16 @@ class HEVC(SettingPanel):
             max_mux=self.widgets.max_mux.currentText(),
             pix_fmt=self.widgets.pix_fmt.currentText().split(":")[1].strip(),
             profile=self.widgets.profile.currentText(),
-            x265_params=self.widgets.x265_params.text().split(":"),
+            hdr10_opt=self.widgets.hdr10_opt.isChecked(),
+            repeat_headers=self.widgets.repeat_headers.isChecked(),
+            aq_mode=self.widgets.aq_mode.currentIndex(),
+            hdr10plus_metadata=self.widgets.hdr10plus_metadata.text().strip().replace("\\", "/"),
             extra=self.ffmpeg_extras,
         )
 
+        x265_params_text = self.widgets.x265_params.text().strip()
+        settings.x265_params = x265_params_text.split(":") if x265_params_text else []
+
         tune = self.widgets.tune.currentText()
         settings.tune = tune if tune.lower() != "default" else None
 
