@@ -8,9 +8,10 @@ from subprocess import run
 
 import pkg_resources
 import reusables
+from box import Box
 from qtpy import QtCore, QtGui, QtWidgets
 
-from fastflix.shared import latest_fastflix, message
+from fastflix.shared import latest_fastflix, message, latest_ffmpeg
 from fastflix.widgets.about import About
 from fastflix.widgets.changes import Changes
 from fastflix.widgets.logs import Logs
@@ -30,6 +31,7 @@ class Container(QtWidgets.QMainWindow):
         self.about = None
         self.init_menu()
         self.config_file = config_file
+        self.config = Box.from_json(filename=self.config_file)
         self.main = Main(self, data_path, work_path, **kwargs)
         self.setCentralWidget(self.main)
         self.setMinimumSize(1200, 600)
@@ -114,6 +116,12 @@ class Container(QtWidgets.QMainWindow):
         )
         version_action.triggered.connect(lambda: latest_fastflix(no_new_dialog=True))
 
+        # TODO Won't enable until can do it non-blocking
+        ffmpeg_update_action = QtWidgets.QAction(
+            self.style().standardIcon(QtWidgets.QStyle.SP_ArrowDown), "Download Newest FFmpeg", self
+        )
+        ffmpeg_update_action.triggered.connect(lambda: latest_ffmpeg(done_alert=True))
+
         help_menu = menubar.addMenu("&Help")
         help_menu.addAction(changes_action)
         help_menu.addAction(report_action)
@@ -121,6 +129,7 @@ class Container(QtWidgets.QMainWindow):
         help_menu.addAction(log_action)
         help_menu.addSeparator()
         help_menu.addAction(version_action)
+        # help_menu.addAction(ffmpeg_update_action)
         help_menu.addSeparator()
         help_menu.addAction(about_action)
 
